@@ -27,15 +27,9 @@ from cubes.vcsfile.schema import Repository
 
 
 Repository.__permissions__['add'] += ('users', ) # XXX Validate this
-Repository.__permissions__['update'] += ('users', ) # XXX Validate this
+Repository.__permissions__['update'] += ('owners', ) # XXX Validate this
 Repository.__permissions__['delete'] += ('owners', ) # XXX Validate this
 
-repotitle = Repository.get_relation('title')
-repotitle.constraints = [RegexpConstraint(r'^\w+$')]
-repotitle.description = _('Repository name (any character within letters, '
-                          'digits and underscore)')
-repotitle.cardinality = '11'
-
 
 class MercurialServerConfig(EntityType):
     __permissions__ = {
@@ -47,7 +41,8 @@ class MercurialServerConfig(EntityType):
         }
     name = String(required=True, maxsize=128, fulltextindexed=True)
     base_url = String(required=True,
-                      description=_('Base URL to access the mercurial server (example: "ssh://hg@my.server")'))
+                      description=_('Base URL to access the mercurial server (example: "ssh://hg@my.server")'),
+                      constraints=[RegexpConstraint(r'.*[^/]$')])
     hgadmin_path = String(required=True, default='hgadmin',
                           description=_('Path of the mercurial repository holding the access '
                                         'configuration file and the keys (relative to base_url)'),
@@ -66,8 +61,8 @@ class hosted_by(RelationDefinition):
     the the MercurialServerConfig object"""
     __permissions__ = {
         'read':   ('managers', 'users'),
-        'add':    ('managers', 'users'),
-        'delete': ('managers', 'users'),
+        'add':    ('managers', RRQLExpression('U has_update_permission S')),
+        'delete': ('managers', RRQLExpression('U has_update_permission S')),
         }
     subject = 'Repository'
     inlined = True
@@ -102,7 +97,7 @@ class SshPubKey(EntityType):
 
 
 class public_key(RelationDefinition):
-    __permissions = {'read':   ('managers', 'users'),
+    __permissions__ = {'read':   ('managers', 'users'),
                      'add':    ('managers', RRQLExpression('S identity U')),
                      'delete': ('managers', RRQLExpression('S identity U')),}
     subject = 'CWUser'
