@@ -7,10 +7,6 @@ class mscui(ui.ui):
     """
     def __init__(self, *args):
         super(mscui, self).__init__(*args)
-        self._output = []
-
-    def write(self, *args, **opts):
-        self._output.extend(args)
-
-    def lastoutput(self):
-        return self._output[-1]
+        self.setconfig('ui', 'interactive', 'false')
+        self.setconfig('ui', 'ssh', 'ssh -o BatchMode=yes -o IdentitiesOnly=yes')
+        self.pushbuffer()
