@@ -7,7 +7,7 @@
 __docformat__ = "restructuredtext en"
 _ = unicode
 
-from cubicweb.web import Redirect
+from cubicweb.web import Redirect, RequestError
 from cubicweb.predicates import is_instance, match_user_groups, match_form_params
 from cubicweb.web.action import Action
 from cubicweb.web.controller import Controller
